@@ -3,9 +3,10 @@ BEGIN {
   $Bread::Board::Service::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Bread::Board::Service::VERSION = '0.29';
+  $Bread::Board::Service::VERSION = '0.30';
 }
 use Moose::Role;
+use Module::Runtime ();
 
 use Moose::Util::TypeConstraints 'find_type_constraint';
 
@@ -52,7 +53,7 @@ has 'lifecycle' => (
         my $lifecycle_role = $lifecycle =~ /^\+/
                  ? substr($lifecycle, 1)
                  : "Bread::Board::LifeCycle::${lifecycle}";
-        Class::MOP::load_class($lifecycle_role);
+        Module::Runtime::require_module($lifecycle_role);
         Class::MOP::class_of($lifecycle_role)->apply($self);
     }
 );
@@ -128,7 +129,7 @@ Bread::Board::Service
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 DESCRIPTION
 
@@ -168,7 +169,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive.
+This software is copyright (c) 2014 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
