@@ -3,9 +3,10 @@ BEGIN {
   $Bread::Board::Service::WithClass::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Bread::Board::Service::WithClass::VERSION = '0.29';
+  $Bread::Board::Service::WithClass::VERSION = '0.30';
 }
 use Moose::Role;
+use Module::Runtime ();
 
 use Bread::Board::Types;
 
@@ -19,7 +20,7 @@ has 'class' => (
 
 before 'get' => sub {
     my $self = shift;
-    Class::MOP::load_class($self->class)
+    Module::Runtime::require_module($self->class)
         if $self->has_class;
 };
 
@@ -35,7 +36,7 @@ Bread::Board::Service::WithClass
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 DESCRIPTION
 
@@ -61,7 +62,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive.
+This software is copyright (c) 2014 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
